@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.h,v 1.77 2006/09/11 00:41:09 vkurland Exp $
+  $Id: FWWindow.h,v 1.79 2007/02/04 03:58:59 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -111,6 +111,7 @@ class FWWindow : public FWBMainWindow_q {
      virtual void fileExit();
      virtual void fileProp();
      virtual void fileAddToRCS();
+     virtual void fileCompare();
      virtual void editCopy();
      virtual void editCut();
      virtual void editDelete();
@@ -216,9 +217,9 @@ class FWWindow : public FWBMainWindow_q {
     RuleSetView* getRuleSetViews(libfwbuilder::FWObject *o) 
     {return ruleSetViews[o];};
 
-    void addPolicyBranchTab(libfwbuilder::PolicyRule *rule);
-    void removePolicyBranchTab(libfwbuilder::PolicyRule *rule);
-    void setPolicyBranchTabName(libfwbuilder::PolicyRule *rule);
+    void addPolicyBranchTab(libfwbuilder::RuleSet *subset);
+    void removePolicyBranchTab(libfwbuilder::RuleSet *subset);
+    void setPolicyBranchTabName(libfwbuilder::RuleSet *subset);
 
     /**
      * panel that wants to open an object in the editor
@@ -243,6 +244,17 @@ class FWWindow : public FWBMainWindow_q {
 
     void scheduleRuleSetRedraw();
 
+    // semi-intelligent way to guess most appropriate
+    // destination directory for various file save or file open
+    // operations. If working directory is configured in
+    // preferences, then getDestDir returns that. If it is not
+    // configured and file name is given on the command line,
+    // directory where that file is located is returned. If
+    // parameter filename is empty, then current directory
+    // is returned (however on windows and mac userDataDir is returned)
+
+    QString getDestDir(const QString &filename);
+
  protected:
 
     virtual void showEvent( QShowEvent *ev);
