@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.cpp,v 1.54 2006/10/22 04:39:36 vkurland Exp $
+  $Id: GroupObjectDialog.cpp,v 1.57 2007/01/08 03:24:48 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -39,6 +39,7 @@
 #include "ObjectManipulator.h"
 #include "FWObjectDrag.h"
 #include "FWObjectClipboard.h"
+#include "ObjectTreeView.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Group.h"
@@ -624,13 +625,24 @@ void GroupObjectDialog::openObject(QIconViewItem *itm)
 
 void GroupObjectDialog::dropped(QDropEvent *ev)
 {
+    if (fwbdebug) qDebug("GroupObjectDialog::dropped");
+
     list<FWObject*> ol;
     if (FWObjectDrag::decode(ev, ol))
     {
         if (ol.size()==0) return;
         for (list<FWObject*>::iterator i=ol.begin(); i!=ol.end(); ++i)
             insertObject( *i );
+        if (fwbdebug) qDebug("GroupObjectDialog::dropped  ev->acceptAction()");
+        ev->acceptAction();
+
+        // see comment in ObjectTreeView.cpp explaining the purpose of
+        // flag process_mouse_release_event
+        ObjectTreeView *otv = om->getCurrentObjectTree();
+        otv->ignoreNextMouseReleaseEvent();
+
     }
+    if (fwbdebug) qDebug("GroupObjectDialog::dropped  done");
 }
 
 void GroupObjectDialog::iconContextMenu(QIconViewItem *itm,const QPoint &p)
