@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4Dialog.cpp,v 1.24 2004/12/09 08:33:20 vkurland Exp $
+  $Id: IPv4Dialog.cpp,v 1.27 2006/05/13 06:53:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -98,7 +98,7 @@ void IPv4Dialog::loadFWObject(FWObject *o)
             netmask->setText( s->getNetmask().toString().c_str() );
     } catch (FWException &ex) {}
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
 
     obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(obj_name);
@@ -122,7 +122,8 @@ void IPv4Dialog::loadFWObject(FWObject *o)
     
 void IPv4Dialog::changed()
 {
-    apply->setEnabled( true );
+    //apply->setEnabled( true );
+    emit changed_sign();
 }
 
 void IPv4Dialog::validate(bool *res)
@@ -160,7 +161,8 @@ void IPv4Dialog::validate(bool *res)
 
 void IPv4Dialog::isChanged(bool *res)
 {
-    *res=(!init && apply->isEnabled());
+    //*res=(!init && apply->isEnabled());
+    
 }
 
 void IPv4Dialog::libChanged()
@@ -209,7 +211,8 @@ void IPv4Dialog::applyChanges()
 
     init=false;
 
-    apply->setEnabled( false );
+    //apply->setEnabled( false );
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void IPv4Dialog::discardChanges()
