@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp,v 1.20 2006/05/24 04:36:54 vkurland Exp $
+  $Id: RuleOptionsDialog.cpp,v 1.21 2006/09/17 18:58:12 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -146,6 +146,19 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
         data.registerOption( pf_source_tracking  , ropt,  "pf_source_tracking" );
         data.registerOption( pf_max_src_nodes    , ropt,  "pf_max_src_nodes" );
         data.registerOption( pf_max_src_states   , ropt,  "pf_max_src_states" );
+
+        data.registerOption( pf_max_src_conn     , ropt,  "pf_max_src_conn" );
+        data.registerOption( pf_max_src_conn_overload_table     ,
+                             ropt,  "pf_max_src_conn_overload_table" );
+        data.registerOption( pf_max_src_conn_flush, ropt,  "pf_max_src_conn_flush" );
+        data.registerOption( pf_max_src_conn_global, ropt, "pf_max_src_conn_global" );
+
+        data.registerOption( pf_max_src_conn_rate_num     , ropt,  "pf_max_src_conn_rate_num" );
+        data.registerOption( pf_max_src_conn_rate_seconds , ropt,  "pf_max_src_conn_rate_seconds" );
+        data.registerOption( pf_max_src_conn_rate_overload_table     ,
+                             ropt,  "pf_max_src_conn_rate_overload_table" );
+        data.registerOption( pf_max_src_conn_rate_flush, ropt,  "pf_max_src_conn_rate_flush" );
+        data.registerOption( pf_max_src_conn_rate_global, ropt, "pf_max_src_conn_rate_global" );
     }
 
     if (platform=="ipfw")
@@ -192,6 +205,14 @@ void RuleOptionsDialog::changed()
     pf_max_src_nodes->setEnabled( pf_source_tracking->isChecked() );
     pf_max_src_states->setEnabled( pf_source_tracking->isChecked() );
 
+    pf_max_src_conn_overload_table->setEnabled( pf_max_src_conn->value()>0 );
+    pf_max_src_conn_flush->setEnabled( pf_max_src_conn->value()>0 );
+    pf_max_src_conn_global->setEnabled( pf_max_src_conn->value()>0 );
+
+    pf_max_src_conn_rate_overload_table->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0);
+    pf_max_src_conn_rate_flush->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0 );
+    pf_max_src_conn_rate_global->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0 );
+
     emit changed_sign();
 }
 
