@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp,v 1.20 2006/05/15 03:13:48 vkurland Exp $
+  $Id: SSHSession.cpp,v 1.23 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,12 +57,14 @@ char  *SSHSession::fingerprintPrompt="key fingerprint is";
 
 
 
-SSHSession::SSHSession(const QString &_h,
+SSHSession::SSHSession(QWidget *_par,
+                       const QString &_h,
                        const QStringList &_args,
                        const QString &_p,
                        const QString &_ep,
                        const list<string> &_in)
 {
+    parent = _par;
     host = _h;
     args = _args;
     pwd  = _p;
@@ -106,7 +108,7 @@ void SSHSession::startSession()
     proc->setCommunication(
         QProcess::Stdin|QProcess::Stdout|QProcess::Stderr|QProcess::DupStderr);
 
-    heartBeatTimer->start(1000);
+    startHeartBeat();
 
     if (fwbdebug)
         qDebug("SSHSession::startSession  this=%p  proc=%p   heartBeatTimer=%p",
@@ -152,7 +154,7 @@ void SSHSession::startSession()
 
     if ( ! proc->start(&env))
     {
-        emit printStdout_sign( tr("Failed to start ssh") );
+        emit printStdout_sign( tr("Failed to start ssh") + "\n" );
         return;
     }
 
@@ -200,7 +202,7 @@ void SSHSession::terminate()
         qDebug("SSHSession::terminate     this=%p  proc=%p   heartBeatTimer=%p",
                this,proc,heartBeatTimer);
 
-    heartBeatTimer->stop();
+    stopHeartBeat();
 
     if (proc!=NULL)
     {
@@ -231,9 +233,10 @@ void SSHSession::terminate()
             delete proc;
             proc=NULL;
             retcode=-1;
-            processExited();
-        };
+//            processExited();
+        }
     }
+    if (fwbdebug) qDebug("SSHSession::terminate   done");
 }
 
 void SSHSession::stateMachine()
@@ -314,6 +317,18 @@ void SSHSession::allDataSent()
     readFromStdout();
 }
 
+void SSHSession::startHeartBeat()
+{
+    if (fwbdebug) qDebug("SSHSession::startHeartBeat");
+    heartBeatTimer->start(1000);
+}
+
+void SSHSession::stopHeartBeat()
+{
+    if (fwbdebug) qDebug("SSHSession::stopHeartBeat");
+    heartBeatTimer->stop();
+}
+
 void SSHSession::heartBeat()
 {
     if (fwbdebug) qDebug("SSHSession::heartBeat");
@@ -330,6 +345,52 @@ void SSHSession::readFromStdout()
 {
     if (proc)
     {
+        QString buf = proc->readStdout();
+        stdoutBuffer=stdoutBuffer + buf;
+
+        bool endsWithLF = buf.endsWith("\n");
+        QString lastLine = "";
+
+        // split on LF
+        QStringList bufLines = QStringList::split("\n",buf,TRUE);
+
+        if (fwbdebug)
+        {
+            qDebug("buf=%s",buf.ascii());
+            qDebug("endsWithLF=%d",endsWithLF);
+            qDebug("bufLines.size()=%d",bufLines.size());
+        }
+
+        // if buf ends with a LF character, the last element in the list is
+        // an empty string
+        if (endsWithLF && bufLines.last().isEmpty())  bufLines.pop_back();
+
+        // if buf does not end with LF, last element in the list is
+        // incomplete line of text
+        if (!endsWithLF)
+        {
+            lastLine = bufLines.last();
+            bufLines.pop_back();
+        }
+
+        // elements that are left in the list  are all complete lines of text
+        for (QStringList::Iterator i=bufLines.begin(); i!=bufLines.end(); ++i)
+        {
+            QString s = pendingLogLine + *i + "\n";
+            if (!quiet)
+            {
+                s.replace('\r',"");    
+                emit printStdout_sign(s);
+            }
+            pendingLogLine = "";
+        }
+
+        pendingLogLine += lastLine;
+
+        stateMachine();
+
+
+#if 0
         QByteArray ba = proc->readStdout();
         if (ba.size()!=0)
         {
@@ -347,6 +408,7 @@ void SSHSession::readFromStdout()
 /* state machine operates on stdoutBuffer directly */
             stateMachine();
         }
+#endif
     }
 }
 
@@ -364,15 +426,36 @@ void SSHSession::readFromStderr()
     }
 }
 
+void SSHSession::sessionComplete(bool err)
+{
+    if (fwbdebug)
+        qDebug(QString("SSHSession::sessionComplete  err=%1").arg(err));
+
+    error = err;
+    if (error)
+        emit sessionFatalError_sign();
+    else
+        emit sessionFinished_sign();
+}
+
 void SSHSession::processExited()
 {
+    if (fwbdebug) qDebug("SSHSession::processExited");
+
     if (proc) retcode=proc->exitStatus();
 
+    if (fwbdebug) qDebug("SSHSession::processExited   proc=%p retcode=%d",proc,retcode);
+
+    // background process has exited now, we do not need proc object anymore
+    delete proc;
+    proc=NULL;
+
     QString exitStatus = (retcode)?QObject::tr("ERROR"):QObject::tr("OK");
     
-    emit printStdout_sign(tr("SSH session terminated, exit status: %1").arg(retcode));
-    if (retcode) error=true;
-    emit sessionFinished_sign();
+    emit printStdout_sign(tr("SSH session terminated, exit status: %1").arg(retcode) + "\n");
+    sessionComplete( retcode!=0 );
+//    if (retcode) error=true;
+//    emit sessionFinished_sign();
 }
 
 bool SSHSession::cmpPrompt(const QString &str,const QString &prompt)
