@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.h,v 1.3 2006/04/24 06:23:58 vkurland Exp $
+  $Id: SSHUnx.h,v 1.4 2006/09/17 05:15:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -42,7 +42,8 @@ class SSHUnx : public SSHSession {
 
 public:
     
-    SSHUnx(const QString &host,
+    SSHUnx(QWidget *parent,
+           const QString &host,
            const QStringList &args,
            const QString &pwd,
            const QString &epwd,
