@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.99 2007/01/30 16:48:10 vkurland Exp $
+  $Id: instDialog.cpp,v 1.101 2007/02/16 08:06:28 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1023,17 +1023,17 @@ void instDialog::initiateCopy(const QString &file)
  * check if cnf.conffile is a full path. If it is, strip the path part
  * and use only the file name for %FWSCRIPT%
  */
-    QString clean_conffile = cnf.conffile.section(QDir::separator(),-1);
+    QString clean_file = file_with_path.section(QDir::separator(),-1);
     if (fwbdebug)
     {
         qDebug("Macro substitutions:");
         qDebug(QString("  cnf.conffile=%1").arg(cnf.conffile));
-        qDebug(QString("  %%FWSCRIPT%%=%1").arg(clean_conffile));
+        qDebug(QString("  %%FWSCRIPT%%=%1").arg(file));
         qDebug(QString("  %%FWDIR%%=%1").arg(cnf.fwdir));
     }
 
     cmd.replace("\n","");
-    cmd.replace("%FWSCRIPT%",clean_conffile);
+    cmd.replace("%FWSCRIPT%",file);
     cmd.replace("%FWDIR%",cnf.fwdir);
     cmd.replace("%FWBPROMPT%",fwb_prompt);
 
