@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp,v 1.118 2006/10/22 18:20:04 vkurland Exp $
+  $Id: main.cpp,v 1.119 2007/02/10 22:41:00 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -232,7 +232,6 @@ int forkpty (int *amaster, char *name, void *unused1, void *unused2)
 
 static struct termios save_termios;
 static int            ttysavefd = -1;
-static enum { RESET, RAW, CBREAK } ttystate = RESET;
 
 int tty_raw(int fd)
 {
@@ -263,7 +262,6 @@ int tty_raw(int fd)
         exit(1);
     }
 
-    ttystate = RAW;
     ttysavefd = fd;
     return 0;
 }
