@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pixAdvancedDialog.cpp,v 1.29 2006/10/21 06:35:12 vkurland Exp $
+  $Id: pixAdvancedDialog.cpp,v 1.30 2007/01/06 22:03:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -781,7 +781,8 @@ void pixAdvancedDialog::reject()
 
 void pixAdvancedDialog::editProlog()
 {
-    SimpleTextEditor edt( pix_prolog_script->text(),
+    SimpleTextEditor edt(this,
+                         pix_prolog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         pix_prolog_script->setText( edt.text() );
@@ -789,7 +790,8 @@ void pixAdvancedDialog::editProlog()
 
 void pixAdvancedDialog::editEpilog()
 {
-    SimpleTextEditor edt( pix_epilog_script->text(),
+    SimpleTextEditor edt(this,
+                         pix_epilog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         pix_epilog_script->setText( edt.text() );
