@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.35 2006/05/16 22:39:59 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp,v 1.38 2007/01/16 05:26:54 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -425,7 +425,7 @@ void  OSConfigurator_linux24::printShellFunctions()
     
     output << "check_file() {"                             << endl;
     output << "  test -r \"$2\" || {"                      << endl;
-    output << "    echo \"Can not find file '$2' referenced by AddressTable object '$1'\"" << endl;
+    output << "    echo \"Can not find file $2 referenced by AddressTable object $1\"" << endl;
     output << "    exit 1"                                 << endl;
     output << "  }"                                        << endl;
     output << "}"                                          << endl;
@@ -654,7 +654,7 @@ string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
         p2=command_line.find(" ",p1);
         string at_var= command_line.substr(p1+1,p2-p1-1);  // skip '$'
         string atfile = rule->getStr("address_table_file");
-        ext_command_line << "grep -Ev '^#' " << atfile << " | ";
+        ext_command_line << "grep -Ev '^#|^;|^\\s*$' " << atfile << " | ";
         ext_command_line << "while read L ; do" << endl;
         ext_command_line << "  set $L; " << at_var << "=$1; ";
         ext_command_line << command_line;
