@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipt.cpp,v 1.59 2006/09/15 05:48:22 vkurland Exp $
+  $Id: ipt.cpp,v 1.60 2006/09/21 06:29:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -92,6 +92,7 @@ static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
 static bool             have_dynamic_interfaces = false;
+static bool             test_mode      = false;
 
 FWObjectDatabase       *objdb = NULL;
 
@@ -176,7 +177,9 @@ int main(int argc, char * const *argv)
             fw_file_name = string(optarg);
             break;
         case 'x':
-            if (*optarg=='p') {
+            if (*optarg=='t') {
+                test_mode = true;
+            } else if (*optarg=='p') {
                 ++optarg;
                 drp  = atoi(optarg);
             } else {
@@ -395,6 +398,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	m.setDebugRule(  drp );
 	m.setVerbose( (bool)(verbose) );
         m.setHaveDynamicInterfaces(have_dynamic_interfaces);
+        if (test_mode) m.setTestMode();
 
 	if ( (mangle_rules_count=m.prolog()) > 0 )
         {
@@ -411,6 +415,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	n.setDebugRule(  drn );
 	n.setVerbose( (bool)(verbose) );
         n.setHaveDynamicInterfaces(have_dynamic_interfaces);
+        if (test_mode) n.setTestMode();
 
 	if ( (nat_rules_count=n.prolog()) > 0 )
         {
@@ -426,6 +431,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	c.setDebugRule(  drp );
 	c.setVerbose( (bool)(verbose) );
         c.setHaveDynamicInterfaces(have_dynamic_interfaces);
+        if (test_mode) c.setTestMode();
 
 	if ( (policy_rules_count=c.prolog()) > 0 )
         {
@@ -438,6 +444,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 	r.setDebugLevel( dl );
 	r.setDebugRule(  drp );
 	r.setVerbose( verbose );
+        if (test_mode) r.setTestMode();
 
 	if ( (routing_rules_count=r.prolog()) > 0 )
         {
