@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw_writers.cpp,v 1.11 2006/05/17 02:30:18 vkurland Exp $
+  $Id: PolicyCompiler_ipfw_writers.cpp,v 1.13 2006/10/15 23:54:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -245,7 +245,13 @@ void PolicyCompiler_ipfw::PrintRule::_printAction(PolicyRule *rule)
         compiler->output << ruleopt->getStr("custom_str") << " ";
         break;
 
-    default:   compiler->output << rule->getActionAsString() << " ";
+    default:
+        compiler->abort(
+            string("Unknown action ") + rule->getActionAsString()
+            + " in rule " + rule->getLabel()
+        );
+
+//   compiler->output << rule->getActionAsString() << " ";
     }
 }
 
@@ -460,7 +466,7 @@ PolicyCompiler_ipfw::PrintRule::PrintRule(const std::string &name) : PolicyCompi
 bool PolicyCompiler_ipfw::PrintRule::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-//    FWOptions*  options = compiler->fw->getOptionsObject();
+    FWOptions*  options = compiler->fw->getOptionsObject();
     FWOptions  *ruleopt = rule->getOptionsObject();
 
     tmp_queue.push_back(rule);
@@ -475,8 +481,16 @@ bool PolicyCompiler_ipfw::PrintRule::processNext()
         compiler->output << quote << "$IPFW" << quote
                          << " set disable 1" << endl;
 
-        compiler->output << quote << "$IPFW" << quote
-                         << " add 1 set 1 check-state ip from any to any"  << endl;
+        /* checking if option add_check_state_rule is absent to
+         * provide for backward compatibility: before 2.1.6 build 131
+         * this option did not exist and compiler alawys generated
+         * check-state rule
+         */
+        if (options->getStr("add_check_state_rule").empty() ||
+            options->getBool("add_check_state_rule"))
+            compiler->output << quote << "$IPFW" << quote
+                             << " add 1 set 1 check-state ip from any to any"  << endl;
+
         compiler->output << endl;
 
         print_once_on_top=false;
